API exported by pygame.display — pygame-ce v2.4.0 documentation

##### pygame-ce documentation

Pygame-ce Home || Help Contents || Reference Index

Most useful stuff: Color | display | draw | event | font | image | key | locals | mixer | mouse | Rect | Surface | time | music | pygame

Advanced stuff: cursors | joystick | mask | sprite | transform | BufferProxy | freetype | gfxdraw | midi | PixelArray | pixelcopy | sndarray | surfarray | math

Other: camera | controller | examples | scrap | system | tests | touch | version

## src_c/display.c

This is the `pygame.display`pygame module to control the display window and screen extension module.

Header file: src_c/include/pygame.h

type pgVidInfoObject

  A pygame object that wraps an SDL_VideoInfo struct. The object returned by `pygame.display.Info()`.

PyTypeObject *pgVidInfo_Type

  The pgVidInfoObject object Python type.

SDL_VideoInfo pgVidInfo_AsVidInfo(PyObject *obj)

  Return the SDL_VideoInfo field of obj, a `pgVidInfo_Type` instance. This macro does not check that obj is not `NULL` or an actual `pgVidInfoObject` object.

PyObject *pgVidInfo_New(SDL_VideoInfo *i)

  Return a new `pgVidInfoObject` object for the SDL_VideoInfo i. On failure, raise a Python exception and return `NULL`.

int pgVidInfo_Check(PyObject *x)

  Return true if x is a `pgVidInfo_Type` instance

  Will return false if x is a subclass of `pgVidInfo_Type`. This macro does not check that x is not `NULL`.

Edit on GitHub